@@ -1,5 +1,5 @@
 package Bio::Roary::ParseGFFAnnotationRole;
-$Bio::Roary::ParseGFFAnnotationRole::VERSION = '3.12.0';
+$Bio::Roary::ParseGFFAnnotationRole::VERSION = '3.13.0';
 # ABSTRACT: A role for parsing a gff file efficiently
 
 use Moose::Role;
@@ -7,7 +7,7 @@ use Bio::Tools::GFF;
 
 has 'gff_file' => ( is => 'ro', isa => 'Str', required => 1 );
 
-has '_tags_to_filter' => ( is => 'ro', isa => 'Str',             default => '(CDS|ncRNA|tRNA|tmRNA|rRNA)' );
+has '_tags_to_filter' => ( is => 'ro', isa => 'Str',             default => 'CDS' );
 has '_gff_parser'     => ( is => 'ro', isa => 'Bio::Tools::GFF', lazy    => 1, builder => '_build__gff_parser' );
 has '_awk_filter'     => ( is => 'ro', isa => 'Str',             lazy    => 1, builder => '_build__awk_filter' );
 
@@ -38,7 +38,7 @@ Bio::Roary::ParseGFFAnnotationRole - A role for parsing a gff file efficiently
 
 =head1 VERSION
 
-version 3.12.0
+version 3.13.0
 
 =head1 SYNOPSIS
 
